==> tex-guy_1.2.4.orig.tar.gz: tex-guy-1.2.4.orig/xgdvi-1.6.1/gui.h <==
/*  XGDVI
 *  Copyright (C) 1999 Hirotsugu Kakugawa
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <gtk/gtk.h>

extern GtkWidget *create_xgdvi (void);
extern GtkWidget *create_FileSelection (void);
extern void       show_FileSelection(void);
extern void       hide_FileSelection(void);
extern void       set_fname_FileSelection(char *fname);
extern GtkWidget *create_PaperSelection (void);
extern void       show_PaperSelection(void);
extern void       hide_PaperSelection(void);
extern GtkWidget *create_BufferSelection (void);
extern void       show_BufferSelection(void);
extern void       hide_BufferSelection(void);
extern GtkWidget *create_Printer ();
extern void       show_Printer(void);
extern void       hide_Printer(void);
extern GtkWidget *create_License (void);
extern void       show_License(void);
extern void       hide_License(void);

extern void       update_page_list(void);
extern void       update_page_display(void);

extern void       gpaper_set(int pap, int ori);


void
on_Buffer_clicked                      (GtkButton       *button,
                                        gpointer         user_data);
void
on_File_clicked                        (GtkButton       *button,
                                        gpointer         user_data);
void
on_Paper_clicked                       (GtkButton       *button,
                                        gpointer         user_data);
void
on_License_clicked                     (GtkButton       *button,
                                        gpointer         user_data);
void
on_Print_clicked                       (GtkButton       *button,
                                        gpointer         user_data);



void  gbuff_select(char *f);
void  gbuff_change_page(char *f, int p);
void  gbuff_kill(char *f);
char *gbuff_get_near(char *f);
char *gbuff_get_next(char *f, int next);
char *gbuff_get_ith(int i);
char *gbuff_get_top(void);
void  gbuff_insert_top(char *f, int p);
void  gbuff_insert_last(char *f, int p);
void  gbuff_insert_here(char *f, int p, char *g);
void  gbuff_move_to_top(char *f);

==> tex-guy_1.3.2.orig.tar.gz: tex-guy-1.3.2/xgdvi-1.6.5/gui.h <==
/*  XGDVI
 *  Copyright (C) 1999-2002  Hirotsugu Kakugawa
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <gtk/gtk.h>

extern GtkWidget *create_xgdvi (void);

extern GtkWidget *create_FileSelection (void);
extern void       show_FileSelection(void);
extern void       hide_FileSelection(void);
extern void       set_fname_FileSelection(char *fname);

extern GtkWidget *create_PaperSelection (void);
extern void       show_PaperSelection(void);
extern void       hide_PaperSelection(void);

extern GtkWidget *create_BufferSelection (void);
extern void       show_BufferSelection(void);
extern void       hide_BufferSelection(void);
extern void       on_buffButtonClose_clicked(GtkButton *button,
					     gpointer user_data);
extern GtkWidget *create_Printer ();
extern void       show_Printer(void);
extern void       hide_Printer(void);

extern GtkWidget *create_License (void);
extern void       show_License(void);
extern void       hide_License(void);

extern void       update_page_list(void);
extern void       update_page_display(void);

extern void       gpaper_set(int pap, int ori);
extern gint       event_key_press(GtkWidget *w, GdkEventKey *ev);


void
on_Buffer_clicked                      (GtkButton       *button,
                                        gpointer         user_data);
void
on_File_clicked                        (GtkButton       *button,
                                        gpointer         user_data);
void
on_Paper_clicked                       (GtkButton       *button,
                                        gpointer         user_data);
void
on_License_clicked                     (GtkButton       *button,
                                        gpointer         user_data);
void
on_Print_clicked                       (GtkButton       *button,
                                        gpointer         user_data);



extern void  gbuff_select(char *f);
extern void  gbuff_change_page(char *f, int p, int n);
extern void  gbuff_kill(char *f);
extern void  gbuff_display_update(void);
extern char *gbuff_get_near(char *f);
extern char *gbuff_get_next(char *f, int next);
extern char *gbuff_get_ith(int i);
extern char *gbuff_get_top(void);
extern void  gbuff_insert_top(char *f, int p);
extern void  gbuff_insert_last(char *f, int p);
extern void  gbuff_insert_here(char *f, int p, char *g);
extern void  gbuff_move_to_top(char *f);
